#ifndef __JSA_STREAMING_NATIVE_H__
#define __JSA_STREAMING_NATIVE_H__
/*
 音频编码数据回调输出函数
 需要调用方实现回调函数，在初始化音频编码的时候传入函数指针，编码后的数据会通过此接口回调出来
 参数说明：
    opaque  编码器opaque（用于标识数据产生自哪个编码器）
    data    音频编码后数据
    datalen 数据长度（字节）
    stamp   时间戳(100ns)
    extrats 歌词时间戳（100ns）
 */
typedef int (* AUDIOENC_CALLBACK)(void*opaque, unsigned char* data, int datalen, long long stamp, long long extrats);

#ifdef __cplusplus
extern "C" {
#endif

/*
 音频数据推送
 编码后音频数据送入，建议在AUDIOENC_CALLBACK回调中调用
 参数说明：
    pBuf        音频数据（PCM或编码后数据，由推流模块初始化决定）
    iSize       数据长度（byte）
    llStamp     数据时间戳（100ns）
    llExtraTS   歌词时间戳（100ns）
*/
int encodeAudio(unsigned char*pBuf, int iSize, long long llStamp, long long llExtraTS);

/*
 音频编码初始化
 成功返回音频编码器handle，失败返回NULL
 参数说明：
    encodertype 编码类型(11 AAC-LC; 12 HEAAC)
    bitrate     编码带宽(bps)
    channelnum  声道数(1 or 2）
    samplerate  采样率
    elementsize 位字节数（2表示16bit）
    opaque      输出用的回调标识
    callbackfn  输出用的回调函数指针
 */
void *encAudioInit(int encodertype, int bitrate, int channelnum, int samplerate, int elementsize, void*opaque, AUDIOENC_CALLBACK callbackfn);

/*
 音频编码输入PCM数据
 成功返回0，注意encAudioClose调用后，此接口不可再被调用
 参数说明：
    handle      编码器handle
    pBuf        输入的PCM数据（short型）
    iSize       输入数据长度（byte）
    llStamp     输入数据时间戳（100ns）
    llExtraTS   歌词时间戳（100ns）
 */
int encAudioInsert(void*handle, unsigned char*pBuf, int iSize, long long llStamp, long long llExtraTS);

/*
 音频编码器关闭
 参数说明：
    handle  编码器handle
 */
void encAudioClose(void*handle);


#ifdef __cplusplus
}
#endif

#endif
